=======
Credits
=======

Author & Maintainer
-------------------

`John D. Boy <https://www.jboy.space>`__, Leiden University

Contributors
------------

- Jeremy Foote (`jdfoote <https://github.com/jdfoote>`__) contributed to the documentation.
- Your name here?
